{ config, pkgs, lib, modulesPath, ... }:

{
  imports =
    [
      (modulesPath + "/virtualisation/proxmox-lxc.nix")
      ../../base.nix
      ../../common/metrics-exporters.nix

      ./services/nginx.nix
      ./services/postgresql.nix
      ./services/flame.nix
  ];

  # Boot and console is handled by proxmoxLXC.
  boot.loader.systemd-boot.enable = lib.mkForce false; # Enabled in base.nix, forced off here.

  # Override proxmox networking
  proxmoxLXC.manageNetwork = true;
  networking = {
    hostName = "sarek";
    defaultGateway = "192.168.10.1";
    nameservers = [ "192.168.10.3" "192.168.11.100" "1.1.1.1" ];
    interfaces."eth0".ipv4 = {
      addresses = [
        { address = "192.168.10.181"; prefixLength = 24; }
      ];
    };
    hostId = "15dd36bc";
  };

  sops.defaultSopsFile = ../../secrets/sarek/sarek.yaml;

  virtualisation.docker.enable = true;
  virtualisation.oci-containers.backend = "docker";

  system.stateVersion = "23.05";
}

